import aiosqlite

from .utils import contains


async def setup_db(db_file):
    db = await aiosqlite.connect(db_file)

    await db.executescript("""
    BEGIN;

    CREATE TABLE IF NOT EXISTS keywords (
        guild_id INTEGER NOT NULL,
        keyword TEXT NOT NULL,
        user_id INTEGER NOT NULL,
        regex INTEGER NOT NULL DEFAULT 0 CHECK(regex IN (0, 1)),
        count INTEGER NOT NULL DEFAULT 0,
        PRIMARY KEY (guild_id, keyword, user_id)
    )
    WITHOUT ROWID;

    CREATE TABLE IF NOT EXISTS guilds (
        guild_id INTEGER NOT NULL PRIMARY KEY,
        prefix TEXT NOT NULL DEFAULT ">"
    );

    CREATE TABLE IF NOT EXISTS users (
        user_id INTEGER NOT NULL PRIMARY KEY,
        disabled INTEGER NOT NULL DEFAULT 0 CHECK(disabled IN (0, 1))
    );

    COMMIT;

    PRAGMA optimize(0x10002);
    PRAGMA main.synchronous = NORMAL;
    """)

    await db.create_function("contains", 3, contains, deterministic=True)

    return db


# TODO: Database versioning and migrations
